@@ -283,6 +283,16 @@ class xlpil(EnchantBase):
             im = im.transpose(PIL.Image.ROTATE_90)
         return im, label
 
+    @staticmethod
+    def flip_direction(im, direction):
+        """
+        :param direction: 标记现在图片是哪个方向：0是正常，1是向右翻转，2是向下翻转，3是向左翻转
+        """
+        im = im.transpose({1: PIL.Image.ROTATE_90,
+                           2: PIL.Image.ROTATE_180,
+                           3: PIL.Image.ROTATE_270}[direction])
+        return im
+
     @staticmethod
     def apply_exif_orientation(im):
         """ 摆正图片角度
